@@ -20,11 +20,11 @@
 #include "config.h"
 #endif
 
-#include "plugin/gtd-plugin-dialog.h"
 #include "gtd-application.h"
 #include "gtd-initial-setup-window.h"
 #include "gtd-manager.h"
 #include "gtd-manager-protected.h"
+#include "gtd-plugin-dialog.h"
 #include "gtd-window.h"
 
 #include <glib.h>
@@ -94,7 +94,9 @@ gtd_application_show_about (GSimpleAction *simple,
   static const gchar *authors[] = {
     "Emmanuele Bassi <ebassi@gnome.org>",
     "Georges Basile Stavracas Neto <georges.stavracas@gmail.com>",
+    "Isaque Galdino <igaldino@gmail.com>"
     "Patrick Griffis <tingping@tingping.se>",
+    "Saiful B. Khan <saifulbkhan@gmail.com>",
     NULL
   };
 
